==> kleopatra-16.07.80.tar.xz: kleopatra-16.07.80/src/commands/exportpaperkeycommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/exportsecretkeycommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2016 Intevation GmbH

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__
#define __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__

#include <commands/gnupgprocesscommand.h>

#include <QString>
#include <QProcess>

class QWidget;

namespace Kleo
{
namespace Commands
{

class ExportPaperKeyCommand : public GnuPGProcessCommand
{
    Q_OBJECT

public:
    explicit ExportPaperKeyCommand(QAbstractItemView *view,
                                   KeyListController *parent);

    static Restrictions restrictions()
    {
        return OnlyOneKey | NeedSecretKey | MustBeOpenPGP;
    }

protected Q_SLOTS:
    void pkProcFinished(int code, QProcess::ExitStatus status);

private:
    QStringList arguments() const Q_DECL_OVERRIDE;
    bool preStartHook(QWidget *parentWidget) const Q_DECL_OVERRIDE;

    QString errorCaption() const Q_DECL_OVERRIDE;

    QString crashExitMessage(const QStringList &) const Q_DECL_OVERRIDE;
    QString errorExitMessage(const QStringList &) const Q_DECL_OVERRIDE;

private:
    QWidget *mParent;
    QProcess mPkProc;
};

}
}

#endif // __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__

==> kleopatra-19.03.90.tar.xz: kleopatra-19.03.90/src/commands/exportpaperkeycommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/exportsecretkeycommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2016 by Bundesamt für Sicherheit in der Informationstechnik
    Software engineering by Intevation GmbH

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__
#define __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__

#include <commands/gnupgprocesscommand.h>

#include <QString>
#include <QProcess>

class QWidget;

namespace Kleo
{
namespace Commands
{

class ExportPaperKeyCommand : public GnuPGProcessCommand
{
    Q_OBJECT

public:
    explicit ExportPaperKeyCommand(QAbstractItemView *view,
                                   KeyListController *parent);

    static Restrictions restrictions()
    {
        return OnlyOneKey | NeedSecretKey | MustBeOpenPGP;
    }

protected Q_SLOTS:
    void pkProcFinished(int code, QProcess::ExitStatus status);

private:
    QStringList arguments() const override;
    bool preStartHook(QWidget *parentWidget) const override;

    QString errorCaption() const override;

    QString crashExitMessage(const QStringList &) const override;
    QString errorExitMessage(const QStringList &) const override;

private:
    QWidget *mParent;
    QProcess mPkProc;
};

}
}

#endif // __KLEOPATRA_COMMMANDS_EXPORTPAPERKEYCOMMAND_H__
